module.exports = {
  description: "replaces value inside ternary operators",
  options: {
    condition: 'first',
    exprIfTrue: 'second',
    exprIfFalse: 'third',
    preventAssignment: true
  }
};
